# User

User explains the user and group to run a Container
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**gid** | **int** | The gid to run the alluxio runtime | 
**group** | **str** | The group name to run the alluxio runtime | [default to '']
**uid** | **int** | The uid to run the alluxio runtime | 
**user** | **str** | The user name to run the alluxio runtime | [default to '']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


